import logging
import logging.handlers
import main
 

class TlsSMTPHandler(logging.handlers.SMTPHandler):
    def emit(self, record):
        """
        Emit a record.

        Format the record and send it to the specified addressees.
        """
        try:
            import smtplib
            #import string # for tls add this line
            try:
                from email.utils import formatdate
            except ImportError:
                formatdate = self.date_time
            port = self.mailport
            if not port:
                port = smtplib.SMTP_PORT
            smtp = smtplib.SMTP(self.mailhost, port)
            msg = self.format(record)
            msg = "From: %s\r\nTo: %s\r\nSubject: %s\r\nDate: %s\r\n\r\n%s" % (
                            self.fromaddr,
                            self.toaddrs,
                            self.getSubject(record),
                            formatdate(), msg)
            if self.username:
                smtp.ehlo() # for tls add this line
                smtp.starttls() # for tls add this line
                smtp.ehlo() # for tls add this line
                smtp.login(self.username, self.password)
            smtp.sendmail(self.fromaddr, self.toaddrs, msg)
            smtp.quit()
        except (KeyboardInterrupt, SystemExit):
            raise
        except:
            self.handleError(record)

logger = logging.getLogger('my.package')

gm = TlsSMTPHandler(("smtp.gmail.com", 587), main.service_mail, main.admin_mail, 'Error found!', (main.service_mail, main.password))
gm.setLevel(logging.ERROR)

logger.addHandler(gm)



import main

print_mode = False

def read(filename):
    data = []
    with open(filename, "r+") as f:
        for line in f:
            if line:
                data.append(line.strip())
            if main.debugMode:
                if print_mode:
                    print("File" + filename + ", read line: " + str(data))
    return data

def write(filename, data):
    with open(filename, "w+") as f:
        f.truncate()
        for line in data:
            f.write(line)
            if main.debugMode:
                if print_mode:
                    print("File" + filename + ", write line: " + str(line))

def append(filename, data):
    with open(filename, "a") as f:
        for line in data:
            f.write(line)
            if main.debugMode:
                if print_mode:
                    print("File: " + filename + ", append line: " + str(line))
